@@ -2,7 +2,7 @@ import glob
 import logging
 import os
 
-from hyp3lib import ExecuteError, OrbitDownloadError
+from hyp3lib import OrbitDownloadError
 from hyp3lib.execute import execute
 from hyp3lib.getParameter import getParameter
 from hyp3lib.get_orb import downloadSentinelOrbitFile
@@ -73,13 +73,11 @@ def par_s1_slc_single(safe_dir, pol='vv', orbit_file=None):
             logging.info(f'Trying to get orbit file information from file {safe_dir}')
             orbit_file, _ = downloadSentinelOrbitFile(safe_dir)
         logging.info('Applying precision orbit information')
-        execute(f'S1_OPOD_vec {acquisition_date}_001.slc.par {orbit_file}')
-        execute(f'S1_OPOD_vec {acquisition_date}_002.slc.par {orbit_file}')
-        execute(f'S1_OPOD_vec {acquisition_date}_003.slc.par {orbit_file}')
+        execute(f'S1_OPOD_vec {acquisition_date}_001.slc.par {orbit_file}', uselogging=True)
+        execute(f'S1_OPOD_vec {acquisition_date}_002.slc.par {orbit_file}', uselogging=True)
+        execute(f'S1_OPOD_vec {acquisition_date}_003.slc.par {orbit_file}', uselogging=True)
     except OrbitDownloadError:
         logging.warning('Unable to fetch precision state vectors... continuing')
-    except ExecuteError:
-        logging.warning('Unable to create *.slc.par files... continuing')
 
     slc = glob.glob('*_00*.slc')
     slc.sort()
